@@ -23,6 +23,7 @@
 """
 import re
 import glob
+import os.path
 import functools
 import datetime
 try:
@@ -621,16 +622,30 @@ class Log(object):
         """The tomorrow log of the same channel."""
         return self.channel[self.date + datetime.timedelta(days=1)]
 
+    @property
+    def filename(self):
+        """The filename of the log.  If not exists, it could be ``None``."""
+        replacers = dict(self.channel.pattern_replacers)
+        replacers["date"] = self.channel.encode_element_key(self.date)
+        files = self.pattern.glob(**replacers)
+        if files:
+            return files[0]
+
+    @property
+    def file_size(self):
+        """The size of the log file in bytes."""
+        filename = self.filename
+        if filename:
+            return os.path.getsize(filename)
+        return 0
+
     def is_logged(self):
         """Returns ``True`` if the channel of the day has logged.
 
         :returns: ``True`` or ``False``
 
         """
-        replacers = dict(self.channel.pattern_replacers)
-        replacers["date"] = self.channel.encode_element_key(self.date)
-        files = self.pattern.glob(**replacers)
-        return bool(files)
+        return bool(self.filename)
 
     def __eq__(self, other):
         return self.channel == other.channel and self.date == other.date
@@ -639,12 +654,10 @@ class Log(object):
         return not (self == other)
 
     def __iter__(self):
-        replacers = dict(self.channel.pattern_replacers)
-        replacers["date"] = self.channel.encode_element_key(self.date)
-        files = self.pattern.glob(**replacers)
-        if not files:
+        filename = self.filename
+        if not filename:
             return
-        with open(files[0]) as file:
+        with open(filename) as file:
             for msg in irclog.parser.parse(file, self.date):
                 yield msg
 
